"use strict";

// @IE9
var add;
var remove;
var contains; // eslint-disable-line import/no-mutable-exports

/* istanbul ignore else */

if (window.document.createElement('div').classList) {
  add = function add(node, name) {
    return node.classList.add(name);
  };

  remove = function remove(node, name) {
    return node.classList.remove(name);
  };

  contains = function contains(node, name) {
    return node.classList.contains(name);
  };
} else {
  add = function add(node, name) {
    var re = new RegExp("(^|\\s)".concat(name, "(\\s|$)"), 'g');

    if (!re.test(node.className)) {
      // eslint-disable-next-line no-param-reassign
      node.className = "".concat(node.className, " ").concat(name).replace(/\s+/g, ' ').replace(/(^ | $)/g, '');
    }
  };

  remove = function remove(node, name) {
    var re = new RegExp("(^|\\s)".concat(name, "(\\s|$)"), 'g'); // eslint-disable-next-line no-param-reassign

    node.className = node.className.replace(re, '$1').replace(/\s+/g, ' ').replace(/(^ | $)/g, '');
  };

  contains = function contains(node, name) {
    return new RegExp("(\\s|^)".concat(name, "(\\s|$)")).test(node.className);
  };
}

var toggle = function toggle(node, name, switcher) {
  if (switcher) {
    add(node, name);
  } else {
    remove(node, name);
  }
};

exports.toggle = toggle;
exports.contains = contains;